==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/el.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others share with you will show up here" : "Τα αρχεία και οι φάκελοι που άλλοι διαμοιράζονται με εσάς θα εμφανιστούν εδώ",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you share will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε θα εμφανιστούν εδώ",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you share by link will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε μέσω συνδέσμου θα εμφανιστούνε εδώ",
    "You can upload into this folder" : "Μπορείτε να μεταφορτώσετε σε αυτόν τον φάκελο",
    "No compatible server found at {remote}" : "Δεν βρέθηκε συμβατός διακομιστής σε {remote}",
    "Invalid server URL" : "Μη έγκυρο URL διακομιστή",
    "Failed to add the public link to your Nextcloud" : "Αποτυχία στην πρόσθεση του κοινού συνδέσμου στο Nextcloud σας",
    "Share" : "Διαμοιρασμός",
    "No expiration date set" : "Δεν ορίστηκε ημερομηνία λήξης",
    "Shared by" : "Διαμοιράστηκε από",
    "Sharing" : "Διαμοιρασμός",
    "File shares" : "Διαμοιράσματα αρχείων",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Downloaded by {email}" : "Κατεβασμένα από {email}",
    "{file} downloaded via public link" : "{file} κατεβασμένα από δημόσιο σύνδεσμο",
    "{email} downloaded {file}" : "{email} κατέβασε {file}",
    "Shared with group {group}" : "Διαμοιρασμένα με την ομάδα {group}",
    "Removed share for group {group}" : "Αφαιρέθηκε ο διαμοιρασμός για την ομάδα {group}",
    "{actor} shared with group {group}" : "{actor} διαμοιράστηκε με την ομάδα {group}",
    "{actor} removed share for group {group}" : "{actor} αφαιρέθηκε ο διαμοιρασμός για την ομάδα {group}",
    "You shared {file} with group {group}" : "Διαμοιραστήκατε {file} με την ομάδα {group}",
    "You removed group {group} from {file}" : "Αφαιρέσατε την ομάδα {group} από {file}",
    "{actor} shared {file} with group {group}" : "{actor} διαμοιράστηκε {file} με την ομάδα {group}",
    "{actor} removed group {group} from {file}" : "{actor} αφαίρεσε την ομάδα {group} από {file}",
    "Shared as public link" : "Διαμοιρασμός με δημόσιο σύνδεσμο",
    "Removed public link" : "Αφαίρεση δημόσιου συνδέσμου",
    "Public link expired" : "Ο δημόσιος σύνδεσμος έληξε",
    "{actor} shared as public link" : "{actor} διαμοιράστηκε με δημόσιος σύνδεσμος",
    "{actor} removed public link" : "{actor} αφαίρεσε δημόσιο σύνδεσμο",
    "Public link of {actor} expired" : "Δημόσιος σύνδεσμος από {actor} έληξε",
    "You shared {file} as public link" : "Διαμοιραστήκατε {file} με δημόσιο σύνδεσμο",
    "You removed public link for {file}" : "Αφαιρέσατε δημόσιο σύνδεσμο για {file}",
    "Public link expired for {file}" : "Δημόσιος σύνδεσμος έληξε για {file}",
    "{actor} shared {file} as public link" : "{actor} διαμοίρασε {file} με δημόσιο σύνδεσμο",
    "{actor} removed public link for {file}" : "{actor} αφαιρέθηκε δημόσιος σύνδεσμος από {file}",
    "Public link of {actor} for {file} expired" : "Δημόσιος σύνδεσμος από {actor} για {file} έλληξε",
    "{user} accepted the remote share" : "{user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό",
    "{user} declined the remote share" : "{user} αποδέχτηκε τον δημόσιο διαμοιρασμό",
    "You received a new remote share {file} from {user}" : "Λάβατε ένα νέο απομακρυσμένο διαμοιρασμό {file} από {user}",
    "{user} accepted the remote share of {file}" : "{user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} declined the remote share of {file}" : "{user} απέρριψε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} unshared {file} from you" : "{user} απέσυρε τον διαμοιρασμό {file} από εσάς",
    "Shared with {user}" : "Διαμοιραζόμενο με {user}",
    "Removed share for {user}" : "Αφαιρέθηκε διαμοιρασμός για {user}",
    "{actor} shared with {user}" : "{actor} διαμοιράστηκε με {user}",
    "{actor} removed share for {user}" : "{actor} αφαιρέθηκε διαμοιρασμός για {user}",
    "Shared by {actor}" : "Διαμοιράστηκε από {actor}",
    "{actor} removed share" : "{actor} αφαίρεσε διαμοιρασμό",
    "You shared {file} with {user}" : "Διαμοιραστήκατε {file} με {user}",
    "You removed {user} from {file}" : "Αφαιρέσατε {user} από {file}",
    "{actor} shared {file} with {user}" : "{actor} διαμοιράστηκε {file} με {user}",
    "{actor} removed {user} from {file}" : "{actor} αφαίρεσε {user} από {file}",
    "{actor} shared {file} with you" : "{actor} διαμοιράστηκε {file} με εσάς",
    "{actor} removed you from {file}" : "{actor} αφαίρεσε εσάς από {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ένα αρχείο ή φάκελος διαμοιρασμένο με mail ή με δημόσιο σύνδεσμο <strong>κατέβηκε</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "Wrong share ID, share doesn't exist" : "Λάθος ID διαμοιρασμού, διαμοιρασμός δεν υπάρχει",
    "could not delete share" : "αδυναμία διαγραφής κοινόχρηστου φακέλου",
    "Could not delete share" : "Αδυναμία διαγραφής κοινόχρηστου φακέλου",
    "Please specify a file or folder path" : "Παρακαλώ καθορίστε την διαδρομή για το αρχείο ή τον φάκελο",
    "Wrong path, file/folder doesn't exist" : "Λάθος διαδρομή, αρχείο/φάκελος δεν υπάρχει",
    "Could not create share" : "Αδυναμία δημιουργίας κοινόχρηστου",
    "invalid permissions" : "μη έγκυρα δικαιόματα",
    "Please specify a valid user" : "Παρακαλώ καθορίστε έναν έγκυρο χρήστη",
    "Group sharing is disabled by the administrator" : "Διαμοιρασμός σε ομάδες είναι απενεργοποιημένος από τον διαχειρηστή",
    "Please specify a valid group" : "Παρακαλώ καθορίστε μια έγκυρη ομάδα",
    "Public link sharing is disabled by the administrator" : "Διαμοιρασμός δημόσιου συνδέσμου είναι απενεργοποιημένος από τον διαχειριστή",
    "Public upload disabled by the administrator" : "Δημόσιο ανέβασμα είναι απενεργοποιημένο από τον διαχειριστή",
    "Public upload is only possible for publicly shared folders" : "Δημόσιο ανέβασμα είναι δυνατό μόνο για δημόσια διαμοιρασμένους φακέλους",
    "Invalid date, date format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία, η μορφή της ημερομηνίας πρέπει να είναι YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Διαμοιρασμός %s απέτυχε επειδή ο εξυπηρετητής δεν επιτρέπει διαμοιρασμούς από τύπο %s",
    "You cannot share to a Circle if the app is not enabled" : "Δεν μπορείτε να διαμοιράσετε σε έναν Κύκλο εάν η εφαρμογή δεν είναι ενεργοποιημένη",
    "Please specify a valid circle" : "Παρακαλούμε προσδιορίστε έναν έγκυρο κύκλο",
    "Unknown share type" : "Άγνωστος τύπος διαμοιρασμού",
    "Not a directory" : "Δεν είναι κατάλογος",
    "Could not lock path" : "Αδυναμία κλειδώματος διαδρομής",
    "Wrong or no update parameter given" : "Λάθος ή καμία παράμετρος αναβάθμισης δεν δόθηκε",
    "Can't change permissions for public share links" : "Δεν μπορούμε να αλλάξουμε δικαιώματα για δημόσια διαμοιρασμένους συνδέσμους",
    "Cannot increase permissions" : "Δεν μπορούμε να αυξήσουμε δικαιώματα",
    "%s is publicly shared" : "%s είναι δημόσια διαμοιρασμένο",
    "Share API is disabled" : "API διαμοιρασμού είναι απενεργοποιημένο",
    "File sharing" : "Διαμοιρασμός αρχείων",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Password" : "Κωδικός πρόσβασης",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Name" : "Όνομα",
    "Share time" : "Χρόνος διαμοιρασμού",
    "Expiration date" : "Ημερομηνία λήξης",
    "Sorry, this link doesn’t seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος μοιάζει να μην ισχύει πια.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more info, please ask the person who sent this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "shared by %s" : "Διαμοιράστηκε από 1 %s",
    "Add to your Nextcloud" : "Προσθήκη στο Nextcloud σου",
    "Download" : "Λήψη",
    "Download %s" : "Λήψη %s",
    "Direct link" : "Άμεσος σύνδεσμος",
    "Upload files to %s" : "Αποστολή αρχείων σε %s",
    "Select or drop files" : "Επιλέξτε ή ρίξτε αρχεία",
    "Uploading files…" : "Αποστολή αρχείων ...",
    "Uploaded files:" : "Αποστολή αρχείων:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/el.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others share with you will show up here" : "Τα αρχεία και οι φάκελοι που άλλοι διαμοιράζονται με εσάς θα εμφανιστούν εδώ",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you share will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε θα εμφανιστούν εδώ",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you share by link will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε μέσω συνδέσμου θα εμφανιστούνε εδώ",
    "You can upload into this folder" : "Μπορείτε να μεταφορτώσετε σε αυτόν τον φάκελο",
    "No compatible server found at {remote}" : "Δεν βρέθηκε συμβατός διακομιστής σε {remote}",
    "Invalid server URL" : "Μη έγκυρο URL διακομιστή",
    "Failed to add the public link to your Nextcloud" : "Αποτυχία στην πρόσθεση του κοινού συνδέσμου στο Nextcloud σας",
    "Share" : "Διαμοιρασμός",
    "No expiration date set" : "Δεν ορίστηκε ημερομηνία λήξης",
    "Shared by" : "Διαμοιράστηκε από",
    "Sharing" : "Διαμοιρασμός",
    "File shares" : "Διαμοιράσματα αρχείων",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Downloaded by {email}" : "Κατεβασμένα από {email}",
    "{file} downloaded via public link" : "{file} κατεβασμένα από δημόσιο σύνδεσμο",
    "{email} downloaded {file}" : "{email} κατέβασε {file}",
    "Shared with group {group}" : "Διαμοιρασμένα με την ομάδα {group}",
    "Removed share for group {group}" : "Αφαιρέθηκε ο διαμοιρασμός για την ομάδα {group}",
    "{actor} shared with group {group}" : "{actor} διαμοιράστηκε με την ομάδα {group}",
    "{actor} removed share for group {group}" : "{actor} αφαιρέθηκε ο διαμοιρασμός για την ομάδα {group}",
    "You shared {file} with group {group}" : "Διαμοιραστήκατε {file} με την ομάδα {group}",
    "You removed group {group} from {file}" : "Αφαιρέσατε την ομάδα {group} από {file}",
    "{actor} shared {file} with group {group}" : "{actor} διαμοιράστηκε {file} με την ομάδα {group}",
    "{actor} removed group {group} from {file}" : "{actor} αφαίρεσε την ομάδα {group} από {file}",
    "Shared as public link" : "Διαμοιρασμός με δημόσιο σύνδεσμο",
    "Removed public link" : "Αφαίρεση δημόσιου συνδέσμου",
    "Public link expired" : "Ο δημόσιος σύνδεσμος έληξε",
    "{actor} shared as public link" : "{actor} διαμοιράστηκε με δημόσιος σύνδεσμος",
    "{actor} removed public link" : "{actor} αφαίρεσε δημόσιο σύνδεσμο",
    "Public link of {actor} expired" : "Δημόσιος σύνδεσμος από {actor} έληξε",
    "You shared {file} as public link" : "Διαμοιραστήκατε {file} με δημόσιο σύνδεσμο",
    "You removed public link for {file}" : "Αφαιρέσατε δημόσιο σύνδεσμο για {file}",
    "Public link expired for {file}" : "Δημόσιος σύνδεσμος έληξε για {file}",
    "{actor} shared {file} as public link" : "{actor} διαμοίρασε {file} με δημόσιο σύνδεσμο",
    "{actor} removed public link for {file}" : "{actor} αφαιρέθηκε δημόσιος σύνδεσμος από {file}",
    "Public link of {actor} for {file} expired" : "Δημόσιος σύνδεσμος από {actor} για {file} έλληξε",
    "{user} accepted the remote share" : "{user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό",
    "{user} declined the remote share" : "{user} αποδέχτηκε τον δημόσιο διαμοιρασμό",
    "You received a new remote share {file} from {user}" : "Λάβατε ένα νέο απομακρυσμένο διαμοιρασμό {file} από {user}",
    "{user} accepted the remote share of {file}" : "{user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} declined the remote share of {file}" : "{user} απέρριψε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} unshared {file} from you" : "{user} απέσυρε τον διαμοιρασμό {file} από εσάς",
    "Shared with {user}" : "Διαμοιραζόμενο με {user}",
    "Removed share for {user}" : "Αφαιρέθηκε διαμοιρασμός για {user}",
    "{actor} shared with {user}" : "{actor} διαμοιράστηκε με {user}",
    "{actor} removed share for {user}" : "{actor} αφαιρέθηκε διαμοιρασμός για {user}",
    "Shared by {actor}" : "Διαμοιράστηκε από {actor}",
    "{actor} removed share" : "{actor} αφαίρεσε διαμοιρασμό",
    "You shared {file} with {user}" : "Διαμοιραστήκατε {file} με {user}",
    "You removed {user} from {file}" : "Αφαιρέσατε {user} από {file}",
    "{actor} shared {file} with {user}" : "{actor} διαμοιράστηκε {file} με {user}",
    "{actor} removed {user} from {file}" : "{actor} αφαίρεσε {user} από {file}",
    "{actor} shared {file} with you" : "{actor} διαμοιράστηκε {file} με εσάς",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ένα αρχείο ή φάκελος διαμοιρασμένο με mail ή με δημόσιο σύνδεσμο <strong>κατέβηκε</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "Wrong share ID, share doesn't exist" : "Λάθος ID διαμοιρασμού, διαμοιρασμός δεν υπάρχει",
    "could not delete share" : "αδυναμία διαγραφής κοινόχρηστου φακέλου",
    "Could not delete share" : "Αδυναμία διαγραφής κοινόχρηστου φακέλου",
    "Please specify a file or folder path" : "Παρακαλώ καθορίστε την διαδρομή για το αρχείο ή τον φάκελο",
    "Wrong path, file/folder doesn't exist" : "Λάθος διαδρομή, αρχείο/φάκελος δεν υπάρχει",
    "Could not create share" : "Αδυναμία δημιουργίας κοινόχρηστου",
    "invalid permissions" : "μη έγκυρα δικαιόματα",
    "Please specify a valid user" : "Παρακαλώ καθορίστε έναν έγκυρο χρήστη",
    "Group sharing is disabled by the administrator" : "Διαμοιρασμός σε ομάδες είναι απενεργοποιημένος από τον διαχειρηστή",
    "Please specify a valid group" : "Παρακαλώ καθορίστε μια έγκυρη ομάδα",
    "Public link sharing is disabled by the administrator" : "Διαμοιρασμός δημόσιου συνδέσμου είναι απενεργοποιημένος από τον διαχειριστή",
    "Public upload disabled by the administrator" : "Δημόσιο ανέβασμα είναι απενεργοποιημένο από τον διαχειριστή",
    "Public upload is only possible for publicly shared folders" : "Δημόσιο ανέβασμα είναι δυνατό μόνο για δημόσια διαμοιρασμένους φακέλους",
    "Invalid date, date format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία, η μορφή της ημερομηνίας πρέπει να είναι YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Διαμοιρασμός %s απέτυχε επειδή ο εξυπηρετητής δεν επιτρέπει διαμοιρασμούς από τύπο %s",
    "You cannot share to a Circle if the app is not enabled" : "Δεν μπορείτε να διαμοιράσετε σε έναν Κύκλο εάν η εφαρμογή δεν είναι ενεργοποιημένη",
    "Please specify a valid circle" : "Παρακαλούμε προσδιορίστε έναν έγκυρο κύκλο",
    "Unknown share type" : "Άγνωστος τύπος διαμοιρασμού",
    "Not a directory" : "Δεν είναι κατάλογος",
    "Could not lock path" : "Αδυναμία κλειδώματος διαδρομής",
    "Wrong or no update parameter given" : "Λάθος ή καμία παράμετρος αναβάθμισης δεν δόθηκε",
    "Can't change permissions for public share links" : "Δεν μπορούμε να αλλάξουμε δικαιώματα για δημόσια διαμοιρασμένους συνδέσμους",
    "Cannot increase permissions" : "Δεν μπορούμε να αυξήσουμε δικαιώματα",
    "shared by %s" : "Διαμοιράστηκε από 1 %s",
    "Download" : "Λήψη",
    "Direct link" : "Άμεσος σύνδεσμος",
    "Add to your Nextcloud" : "Προσθήκη στο Nextcloud σου",
    "Share API is disabled" : "API διαμοιρασμού είναι απενεργοποιημένο",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Name" : "Όνομα",
    "Share time" : "Χρόνος διαμοιρασμού",
    "Expiration date" : "Ημερομηνία λήξης",
    "Sorry, this link doesn’t seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος μοιάζει να μην ισχύει πια.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more info, please ask the person who sent this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "Download %s" : "Λήψη %s",
    "Upload files to %s" : "Αποστολή αρχείων σε %s",
    "Select or drop files" : "Επιλέξτε ή ρίξτε αρχεία",
    "Uploading files…" : "Αποστολή αρχείων ...",
    "Uploaded files:" : "Αποστολή αρχείων:",
    "{actor} removed you from {file}" : "{actor} αφαίρεσε εσάς από {file}",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Password" : "Κωδικός πρόσβασης"
},
"nplurals=2; plural=(n != 1);");
